@@ -21,7 +21,7 @@ OC.L10N.register(
     "Appointments" : "Tapaamiset",
     "Schedule appointment \"%s\"" : "Ajoita tapaaminen \"%s\"",
     "Schedule an appointment" : "Ajoita tapaaminen",
-    "%1$s - %2$s" : "%1$s - %2$s",
+    "Appointment Description:" : "Tapaamisen kuvaus:",
     "Prepare for %s" : "Valmistaudu tapahtumaan \"%s\"",
     "Your appointment \"%s\" with %s needs confirmation" : "Tapaaminen \"%s\"  henkilön %s kanssa vaatii vahvistamisen",
     "Dear %s, please confirm your booking" : "%s, ole hyvä ja vahvista varauksesi",
@@ -37,6 +37,19 @@ OC.L10N.register(
     "Comment:" : "Kommentti:",
     "You have a new appointment booking \"%s\" from %s" : "Sinulla on uusi tapaamisvaraus \"%s\" henkilöltä %s",
     "Dear %s, %s (%s) booked an appointment with you." : "%s, %s (%s) varasi tapaamisen kanssasi.",
+    "%s has proposed a meeting" : "%s ehdotti tapaamista",
+    "%s has updated a proposed meeting" : "%s päivitti kokousehdotuksen",
+    "%s has canceled a proposed meeting" : "%s perui kokousehdotuksen",
+    "Dear %s, a new meeting has been proposed" : "%s, uutta kokousta on ehdotettu",
+    "Dear %s, a proposed meeting has been updated" : "%s, ehdotettu kokous on päivitetty",
+    "Dear %s, a proposed meeting has been cancelled" : "%s, ehdotettu kokous on peruttu",
+    "Location:" : "Sijainti:",
+    "%1$s minutes" : "%1$s minuuttia",
+    "Duration:" : "Kesto:",
+    "Dates:" : "Päivät:",
+    "Respond" : "Vastaa",
+    "[Proposed] %1$s" : "[Ehdotettu] %1$s",
+    "Calendar App" : "Kalenterisovellus",
     "A Calendar app for Nextcloud" : "Kalenterisovellus Nextcloudille",
     "Previous day" : "Edellinen päivä",
     "Previous week" : "Edellinen viikko",
@@ -67,8 +80,11 @@ OC.L10N.register(
     "Enable calendar \"{calendar}\"" : "Ota käyttöön kalenteri \"{calendar}\"",
     "Enable untitled calendar" : "Ota nimetön kalenteri käyttöön",
     "An error occurred, unable to change visibility of the calendar." : "Tapahtui virhe. Kalenterin näkyvyyttä ei voitu muuttaa.",
+    "Calendar link copied to clipboard." : "Kalenterilinkki kopioitu leikepöydälle.",
+    "Calendar link could not be copied to clipboard." : "Kalenterilinkkiä ei voitu kopioida leikepöydälle.",
     "Untitled calendar" : "Nimetön kalenteri",
     "Shared with you by" : "Jaettu sinulle käyttäjältä",
+    "Copy public link" : "Kopioi julkinen linkki",
     "Edit and share calendar" : "Muokkaa/jaa kalenteri",
     "Edit calendar" : "Muokkaa kalenteria",
     "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Poistetaan kalenterin jako {countdown} sekunnin kuluttua","Poistetaan kalenterin jako {countdown} sekunnin kuluttua"],
@@ -85,8 +101,6 @@ OC.L10N.register(
     "Creating subscription …" : "Luodaan tilaus …",
     "Add public holiday calendar" : "Lisää juhlapäiväkalenteri",
     "Add custom public calendar" : "Lisää mukautettu julkinen kalenteri",
-    "Calendar link copied to clipboard." : "Kalenterilinkki kopioitu leikepöydälle.",
-    "Calendar link could not be copied to clipboard." : "Kalenterilinkkiä ei voitu kopioida leikepöydälle.",
     "Copy subscription link" : "Kopioi tilauslinkki",
     "Copying link …" : "Kopioidaan linkki …",
     "Copied link" : "Linkki kopioitu",
@@ -110,7 +124,6 @@ OC.L10N.register(
     "Could not update calendar order." : "Kalenterin järjestystä ei voitu päivittää.",
     "Shared calendars" : "Jaetut kalenterit",
     "Deck" : "Pakka",
-    "Hidden" : "Piilotettu",
     "Internal link" : "Sisäinen linkki",
     "A private link that can be used with external clients" : "Yksityinen linkki, jota voi käyttää ulkoisten asiakkaiden kanssa",
     "Copy internal link" : "Kopioi sisäinen linkki",
@@ -120,7 +133,6 @@ OC.L10N.register(
     "Embed code could not be copied to clipboard." : "Upotuskoodia ei voitu kopioida leikepöydälle.",
     "Unpublishing calendar failed" : "Kalenterin julkaisun peruminen epäonnistui",
     "Share link" : "Jaa linkki",
-    "Copy public link" : "Kopioi julkinen linkki",
     "Send link to calendar via email" : "Lähetä kalenteriin johtava linkki sähköpostitse",
     "Enter one address" : "Kirjoita yksi osoite",
     "Sending email …" : "Lähetetään sähköpostia …",
@@ -133,15 +145,23 @@ OC.L10N.register(
     "{teamDisplayName} (Team)" : "{teamDisplayName} (tiimi)",
     "An error occurred while unsharing the calendar." : "Kalenterin jaon poistamisessa tapahtui virhe.",
     "An error occurred, unable to change the permission of the share." : "Tapahtui virhe, jaon käyttöoikeuksia ei pysty muokkaamaan.",
-    "can edit" : "voi muokata",
     "Unshare with {displayName}" : "Poista jako kohteesta {displayName}",
     "Share with users or groups" : "Jaa käyttäjien tai ryhmien kanssa",
     "No users or groups" : "Ei käyttäjiä tai ryhmiä",
     "Failed to save calendar name and color" : "Kalenterin nimen ja värin tallentaminen epäonnistui",
-    "Calendar name …" : "Kalenterin nimi…",
+    "Never show me as busy (set this calendar to transparent)" : "Älä ikinä näytä minua varattuna (aseta tämä kalenteri läpinäkyväksi)",
     "Share calendar" : "Jaa kalenteri",
     "Unshare from me" : "Lopeta jako minulle",
     "Save" : "Tallenna",
+    "No title" : "Ei otsikkoa",
+    "Are you sure you want to delete \"{title}\"?" : "Haluatko varmasti poistaa \"{title}\"?",
+    "Deleting proposal \"{title}\"" : "Poistetaan ehdotus \"{title}\"",
+    "Successfully deleted proposal" : "Ehdotus poistettu",
+    "Failed to delete proposal" : "Ehdotuksen poistaminen epäonnistui",
+    "Failed to retrieve proposals" : "Ehdotusten noutaminen epäonnistui",
+    "Meeting proposals" : "Kokousehdotukset",
+    "No active meeting proposals" : "Ei aktiivisia kokousehdotuksia",
+    "View" : "Näkymä",
     "Import calendars" : "Tuo kalenterit",
     "Please select a calendar to import into …" : "Valitse kalenteri, johon tuodaan …",
     "Filename" : "Tiedostonimi",
@@ -152,14 +172,16 @@ OC.L10N.register(
     "Pick" : "Valitse",
     "Invalid location selected" : "Virheellinen sijainti valittu",
     "Attachments folder successfully saved." : "Liitteiden kansio tallennettu.",
-    "Default attachments location" : "Liitteiden oletussijainti",
+    "Error on saving attachments folder." : "Virhe liitetiedostokansiota tallennettaessa.",
+    "Attachments folder" : "Liitteiden kansio",
     "{filename} could not be parsed" : "Tiedostoa {filename} ei voitu jäsentää",
     "No valid files found, aborting import" : "Kelvollisia tiedostoja ei löytynyt, lopetetaan tuonti",
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["Tuotiin onnistuneesti %n tapahtuma","Tuotiin onnistuneesti %n tapahtumaa"],
     "Import partially failed. Imported {accepted} out of {total}." : "Tuonti epäonnistui osittain. Tuotiin {accepted}/{total}.",
     "Automatic" : "Automaattinen",
-    "Automatic ({detected})" : "Automaattinen ({detected})",
+    "Automatic ({timezone})" : "Automaattinen ({timezone})",
     "New setting was not saved successfully." : "Uutta asetusta ei tallennettu onnistuneesti.",
+    "Timezone" : "Aikavyöhyke",
     "Navigation" : "Navigointi",
     "Previous period" : "Edellinen jakso",
     "Next period" : "Seuraava jakso",
@@ -177,27 +199,28 @@ OC.L10N.register(
     "Save edited event" : "Tallenna muokattu tapahtuma",
     "Delete edited event" : "Poista muokattu tapahtuma",
     "Duplicate event" : "Tee kaksoiskappale tapahtumasta",
-    "Shortcut overview" : "Pikakuvakenäkymä",
     "or" : "tai",
     "Calendar settings" : "Kalenteriasetukset",
     "At event start" : "Tapahtuman alkaessa",
     "No reminder" : "Ei muistutusta",
     "Failed to save default calendar" : "Oletuskalenterin tallentaminen epäonnistui",
-    "CalDAV link copied to clipboard." : "CalDAV-linkki kopioitu leikepöydälle.",
-    "CalDAV link could not be copied to clipboard." : "CalDAV-linkkiä ei voitu kopioida leikepöydälle.",
-    "Enable birthday calendar" : "Käytä syntymäpäiväkalenteria",
-    "Show tasks in calendar" : "Näytä tehtävät kalenterissa",
-    "Enable simplified editor" : "Käytä yksinkertaistettua muokkainta",
-    "Limit the number of events displayed in the monthly view" : "Rajoita kuukausinäkymässä näytettävien tapahtumien määrää",
-    "Show weekends" : "Näytä viikonloput",
-    "Show week numbers" : "Näytä viikkonumerot",
-    "Time increments" : "Aikavälit",
+    "General" : "Yleiset",
     "Default calendar for incoming invitations" : "Oletuskalenteri saapuville kutsuille",
+    "Availability settings" : "Saatavuuden asetukset",
+    "CalDAV" : "CalDAV",
+    "Access Nextcloud calendars from other apps and devices" : "Käytä Nextcloud-kalentereita muista sovelluksista ja laitteilta",
+    "CalDAV URL" : "CalDAV:in URL-osoite",
+    "Server Address for iOS and macOS" : "Palvelinosoite iOS:lle ja macOS:lle",
+    "Appearance" : "Ulkoasu",
+    "Birthday calendar" : "Syntymäpäiväkalenteri",
+    "Tasks in calendar" : "Tehtävät kalenterissa",
+    "Weekends" : "Viikonloput",
+    "Week numbers" : "Viikkonumerot",
+    "Limit number of events shown in Month view" : "Rajoita kuukausinäkymässä näytettävien tapahtumien määrää",
+    "Editing" : "Muokkaaminen",
     "Default reminder" : "Oletusmuistutus",
-    "Copy primary CalDAV address" : "Kopioi ensisijainen CalDAV-osoite",
-    "Copy iOS/macOS CalDAV address" : "Kopioi iOS:in/macOS:n CalDAV-osoite",
-    "Personal availability settings" : "Henkilökohtaiset saatavuusasetukset",
-    "Show keyboard shortcuts" : "Näytä pikanäppäimet",
+    "Simple event editor" : "Yksinkertainen tapahtumamuokkain",
+    "Files" : "Tiedostot",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minuutti","{duration} minuuttia"],
     "0 minutes" : "0 minuuttia",
     "_{duration} hour_::_{duration} hours_" : ["{duration} tunti","{duration} tuntia"],
@@ -212,6 +235,7 @@ OC.L10N.register(
     "Create appointment schedule" : "Luo tapaamisaikataulu",
     "Edit appointment schedule" : "Muokkaa tapaamisaikataulua",
     "Update" : "Päivitä",
+    "(copy)" : "(kopioi)",
     "Appointment name" : "Tapaamisen nimi",
     "Location" : "Sijainti",
     "Create a Talk room" : "Luo Talk-huone",
@@ -249,11 +273,20 @@ OC.L10N.register(
     "Could not book the appointment. Please try again later or contact the organizer." : "Tapaamista ei voitu kirjata. Ole hyvä ja yritä myöhemmin uudelleen tai ota yhteyttä järjestäjään.",
     "Back" : "Takaisin",
     "Book appointment" : "Varaa tapaaminen",
+    "Error fetching Talk conversations." : "Virhe noudettaessa Talk-keskusteluja.",
+    "Conversation does not have a valid URL." : "Keskustelulla ei ole kelvollista URL-osoitetta.",
+    "Successfully added Talk conversation link to location." : "Talk-keskustelulinkki lisätty sijaintiin.",
+    "Successfully added Talk conversation link to description." : "Talk-keskustelulinkki lisätty kuvaukseen.",
+    "Talk conversation for event" : "Tapahtuman Talk-keskustelu",
     "Error creating Talk conversation" : "Virhe luotaessa Talk-keskustelua",
     "Select a Talk Room" : "Valitse Talk-huone",
-    "Add Talk conversation" : "Lisää Talk-keskustelu",
     "Fetching Talk rooms…" : "Noudetaan Talk-huoneita…",
+    "No Talk room available" : "Talk-huonetta ei ole käytettävissä",
+    "Select existing conversation" : "Valitse olemassa oleva keskustelu",
     "Select conversation" : "Valitse keskustelu",
+    "Or create a new conversation" : "Tai luo uusi keskustelu",
+    "Create public conversation" : "Luo julkinen keskustelu",
+    "Create private conversation" : "Luo yksityinen keskustelu",
     "on" : "päivä",
     "at" : "kellonaika",
     "before at" : "ennen",
@@ -300,6 +333,7 @@ OC.L10N.register(
     "Awaiting response" : "Odottaa vastausta",
     "Checking availability" : "Tarkistetaan saatavuutta",
     "Has not responded to {organizerName}'s invitation yet" : "Ei ole vielä vastanut järjestäjän {organizerName} kutsuun",
+    "Suggested times" : "Ehdotetut ajat",
     "chairperson" : "puheenjohtaja",
     "required participant" : "vaadittu osallistuja",
     "optional participant" : "valinnainen osallistuja",
@@ -307,9 +341,12 @@ OC.L10N.register(
     "{attendee} ({role})" : "{attendee} ({role})",
     "Availability of attendees, resources and rooms" : "Osallistujien, resurssien ja huoneiden saatavuus",
     "Suggestion accepted" : "Ehdotus hyväksytty",
+    "Previous date" : "Edellinen päivä",
+    "Next date" : "Seuraava päivä",
     "Legend" : "Selite",
     "Out of office" : "Ulkona toimistolta",
     "Attendees:" : "Osallistujat:",
+    "local time" : "paikallinen aika",
     "Done" : "Valmis",
     "Search room" : "Etsi huonetta",
     "Room name" : "Huoneen nimi",
@@ -328,10 +365,10 @@ OC.L10N.register(
     "Accept" : "Hyväksy",
     "Decline" : "Kieltäydy",
     "Tentative" : "Alustava",
+    "Copied to clipboard" : "Kopioitu leikepöydälle",
+    "Failed to copy" : "Kopiointi epäonnistui",
+    "Copy name and email address" : "Kopioi nimi ja sähköpostiosoite",
     "No attendees yet" : "Ei vielä osallistujia",
-    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} kutsuttu, {confirmedCount} vahvistettu",
-    "Successfully appended link to talk room to description." : "Linkki Talk-huoneeseen lisättiin onnistuneesti kuvaukseen.",
-    "Error creating Talk room" : "Virhe luotaessa Talk-huonetta",
     "Attendees" : "Osallistujat",
     "Remove group" : "Poista ryhmä",
     "Remove attendee" : "Poista osallistuja",
@@ -346,17 +383,15 @@ OC.L10N.register(
     "(organizer)" : "(järjestäjä)",
     "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "[linkopen]Lisää sähköpostiosoitteesi henkilökohtaisiin asetuksiisi[linkclose] lähettääksesi kutsuja ja hallitaksesi vastauksia.",
     "Remove color" : "Poista väri",
-    "Event title" : "Tapahtuman otsikko",
+    "Title" : "Nimeke",
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Koko päivän tapahtumia, jotka ovat osa toistuvaa tapahtumaa, ei voida muokata.",
-    "From" : "Lähettäjä",
-    "To" : "Vastaanottaja",
+    "From" : "Alkaen",
+    "To" : "Päättyen",
     "Repeat" : "Toista",
-    "_time_::_times_" : ["kerran","kertaa"],
     "never" : "ei koskaan",
     "on date" : "päivänä",
     "after" : "jälkeen",
     "End repeat" : "Lopeta toisto",
-    "Select to end repeat" : "Valitse lopettaaksesi toiston",
     "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Tämä tapahtuma on toistuvaan tapahtumaan tehty poikkeus. Et voi lisätä tähän uutta toistuvuutta.",
     "first" : "ensimmäinen",
     "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Muutokset toistuvuusasetukseen vaikuttavat vain tähän ja tuleviin tapahtumakertoihin.",
@@ -394,19 +429,15 @@ OC.L10N.register(
     "Update this occurrence" : "Päivitä tämä esiintymä",
     "Public calendar does not exist" : "Julkista kalenteria ei ole olemassa",
     "Maybe the share was deleted or has expired?" : "Kenties jako poistettiin tai se vanheni.",
-    "from {formattedDate}" : "alkaen {formattedDate}",
-    "to {formattedDate}" : "päättyen {formattedDate}",
-    "on {formattedDate}" : "päivänä {formattedDate}",
-    "from {formattedDate} at {formattedTime}" : "alkaen {formattedDate} klo {formattedTime}",
-    "to {formattedDate} at {formattedTime}" : "päättyen {formattedDate} klo {formattedTime}",
-    "on {formattedDate} at {formattedTime}" : "päivänä {formattedDate} klo {formattedTime}",
-    "{formattedDate} at {formattedTime}" : "{formattedDate} klo {formattedTime}",
-    "Please enter a valid date" : "Kirjoita kelvollinen päivä",
-    "Please enter a valid date and time" : "Kirjoita kelvollinen päivä ja aika",
-    "Select a time zone" : "Valitse aikavyöhyke",
-    "Please select a time zone:" : "Valitse aikavyöhyke:",
-    "Pick a time" : "Valitse aika",
-    "Pick a date" : "Valitse päivä",
+    "Attendance required" : "Osallistuminen vaaditaan",
+    "Attendance optional" : "Osallistuminen valinnaista",
+    "Remove participant" : "Poista osallistuja",
+    "Yes" : "Kyllä",
+    "No" : "Ei",
+    "Maybe" : "Ehkä",
+    "None" : "Ei mitään",
+    "Create a meeting for this date and time" : "Luo kokous tälle päivälle ja ajankohdalle",
+    "Create" : "Luo",
     "Type to search time zone" : "Kirjoita etsiäksesi aikavyöhykettä",
     "Global" : "Julkinen",
     "Holidays in {region}" : "Juhlapäivä alueella {region}",
@@ -434,17 +465,51 @@ OC.L10N.register(
     "Personal" : "Henkilökohtainen",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Automaattinen aikavyöhykkeentunnistus määritti aikavyöhykkeesi olevan UTC. \nTämä johtuu todennäköisesti selaimesi tietoturva-asetuksista.\nOle hyvä ja aseta aikavyöhykkeesi manuaalisesti kalenterin asetuksista.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Asettamaasi aikavyöhykettä ({timezoneId}) ei löytynyt. Vaihdetaan takaisin UTC:hen.\nOle hyvä ja vaihda aikavyöhykkeesi asetuksista ja ilmoita tästä ongelmasta.",
+    "Show unscheduled tasks" : "Näytä ajastamattomat tehtävät",
+    "Unscheduled tasks" : "Ajastamattomat tehtävät",
+    "Discard changes" : "Hylkää muutokset",
     "Edit event" : "Muokkaa tapahtumaa",
     "Event does not exist" : "Tapahtumaa ei ole olemassa",
     "Delete this occurrence" : "Poista tämä esiintymä",
     "Delete this and all future" : "Poista tämä ja kaikki tulevat",
     "All day" : "Koko päivä",
+    "Add Talk conversation" : "Lisää Talk-keskustelu",
     "Managing shared access" : "Jaetun pääsyn hallinta",
     "Deny access" : "Estä pääsy",
     "Invite" : "Kutsu",
+    "Discard changes?" : "Hylätäänkö muutokset?",
+    "Are you sure you want to discard the changes made to this event?" : "Haluatko varmasti hylätä tähän tapahtumaan tehdyt muutokset?",
     "_User requires access to your file_::_Users require access to your file_" : ["Käyttäjä tarvitsee pääsyn tiedostoosi","Käyttäjät tarvitsevat pääsyn tiedostoosi"],
     "Untitled event" : "Nimetön tapahtuma",
     "Close" : "Sulje",
+    "This event was cancelled" : "Tämä tapahtuma peruttiin",
+    "Meeting proposals overview" : "Kokousehdotusten yhteenveto",
+    "Edit meeting proposal" : "Muokkaa kokousehdotusta",
+    "Create meeting proposal" : "Luo kokousehdotus",
+    "Update meeting proposal" : "Päivitä kokousehdotus",
+    "Saving proposal \"{title}\"" : "Tallennetaan ehdotus \"{title}\"",
+    "Successfully saved proposal" : "Ehdotus tallennettu",
+    "Failed to save proposal" : "Ehdotuksen tallentaminen epäonnistui",
+    "Creating meeting for {date}" : "Luo kokous päivälle {date}",
+    "Please enter a valid duration in minutes." : "Kirjoita kelvollinen kesto minuutteina.",
+    "Failed to fetch proposals" : "Ehdotusten noutaminen epäonnistui",
+    "Selected" : "Valittu",
+    "No Description" : "Ei kuvausta",
+    "No Location" : "Ei sijaintia",
+    "Edit this meeting proposal" : "Muokkaa tätä kokousehdotusta",
+    "Delete this meeting proposal" : "Poista tämä kokousehdotus",
+    "Participants" : "Osallistujat",
+    "Selected times" : "Valitut ajat",
+    "Less days" : "Vähemmän päiviä",
+    "More days" : "Enemmän päiviä",
+    "Loading meeting proposal" : "Ladataan kokousehdotusta",
+    "No meeting proposal found" : "Kokousehdotusta ei löytynyt",
+    "Thank you for your response!" : "Kiitos vastauksestasi!",
+    "Unknown User" : "Tuntematon käyttäjä",
+    "No Title" : "Ei otsikkoa",
+    "No Duration" : "Ei kestoa",
+    "Select a different time zone" : "Valitse eri aikavyöhyke",
+    "Submit" : "Lähetä",
     "Subscribe to {name}" : "Tilaa {name}",
     "Export {name}" : "Vie {name}",
     "Show availability" : "Näytä saatavuus",
@@ -497,17 +562,19 @@ OC.L10N.register(
     "last" : "viimeinen",
     "Untitled task" : "Nimetön tehtävä",
     "Please ask your administrator to enable the Tasks App." : "Pyydä järjestelmänvalvojaa ottamaan Tasks-sovellus käyttöön",
+    "You are not allowed to edit this event as an attendee." : "Sinulla ei ole oikeutta muokata tätä tapahtumaa osallistujan roolissa.",
     "W" : "Vko",
     "%n more" : "%n lisää",
     "No events to display" : "Ei tapahtumia näytettäväksi",
+    "All participants declined" : "Kaikki osallistujat kieltäytyivät",
     "Please confirm your participation" : "Vahvista osallistumisesi",
     "You declined this event" : "Kieltäydyit tästä tapahtumasta",
     "Your participation is tentative" : "Osallistumisesi on alustava.",
     "_+%n more_::_+%n more_" : ["+%n lisää","+%n lisää"],
     "No events" : "Ei tapahtumia",
     "Create a new event or change the visible time-range" : "Luo uusi tapahtuma tai vaihda näkyvää aikajanaa",
-    "Failed to save event" : "Tapahtuman tallentaminen epäonnistui",
     "It might have been deleted, or there was a typo in a link" : "Se saattaa olla poistettu, tai linkissä oli kirjoitusvirhe",
+    "Failed to save event" : "Tapahtuman tallentaminen epäonnistui",
     "It might have been deleted, or there was a typo in the link" : "Se saattaa olla poistettu, tai linkissä oli kirjoitusvirhe",
     "Meeting room" : "Kokoushuone",
     "Lecture hall" : "Luentosali",
@@ -517,7 +584,6 @@ OC.L10N.register(
     "When shared show full event" : "Jaettaessa näytä koko tapahtuma",
     "When shared show only busy" : "Jaettaessa näytä vain varattuna oleminen",
     "When shared hide this event" : "Jaettaessa piilota tämä tapahtuma",
-    "The visibility of this event in shared calendars." : "Tämän tapahtuman näkyvyys jaetuissa kalentereissa.",
     "Add a location" : "Lisää sijainti",
     "Add a description\n\n- What is this meeting about\n- Agenda items\n- Anything participants need to prepare" : "Lisää kuvaus\n\n- Mitä tapaamisessa käsitellään\n- Asialista\n- Mitä hyvänsä mihin osallistujien tulisi valmistautua",
     "Status" : "Tila",
@@ -536,19 +602,59 @@ OC.L10N.register(
     "Error while sharing file with user" : "Virhe tiedostoa jakaessa käyttäjän kanssa",
     "Error creating a folder {folder}" : "Virhe luotaessa kansiota {folder}",
     "Attachment {fileName} already exists!" : "Liite {fileName} on jo olemassa!",
+    "Attachment {fileName} added!" : "Liite {fileName} lisätty!",
+    "An error occurred during uploading file {fileName}" : "Tiedostoa {fileName} lähettäessä tapahtui virhe",
     "An error occurred during getting file information" : "Tiedostojen tietoja noutaessa tapahtui virhe",
-    "Talk conversation for event" : "Tapahtuman Talk-keskustelu",
     "An error occurred, unable to delete the calendar." : "Tapahtui virhe, kalenteria ei voitu poistaa.",
     "Imported {filename}" : "Tuotiin {filename}",
     "This is an event reminder." : "Tämä on tapahtuman muistutus.",
     "Appointment not found" : "Tapaamista ei löydy",
     "User not found" : "Käyttäjää ei löydy",
-    "Create a new conversation" : "Luo uusi keskustelu",
-    "Reminder" : "Muistutus",
-    "+ Add reminder" : "+ Lisää muistutus",
-    "with" : "kanssa",
-    "Available times:" : "Saatavilla olevat ajat:",
-    "Suggestions" : "Ehdotukset",
-    "Details" : "Tiedot"
+    "%1$s - %2$s" : "%1$s - %2$s",
+    "Hidden" : "Piilotettu",
+    "can edit" : "voi muokata",
+    "Calendar name …" : "Kalenterin nimi…",
+    "Default attachments location" : "Liitteiden oletussijainti",
+    "Automatic ({detected})" : "Automaattinen ({detected})",
+    "Shortcut overview" : "Pikakuvakenäkymä",
+    "CalDAV link copied to clipboard." : "CalDAV-linkki kopioitu leikepöydälle.",
+    "CalDAV link could not be copied to clipboard." : "CalDAV-linkkiä ei voitu kopioida leikepöydälle.",
+    "Enable birthday calendar" : "Käytä syntymäpäiväkalenteria",
+    "Show tasks in calendar" : "Näytä tehtävät kalenterissa",
+    "Enable simplified editor" : "Käytä yksinkertaistettua muokkainta",
+    "Limit the number of events displayed in the monthly view" : "Rajoita kuukausinäkymässä näytettävien tapahtumien määrää",
+    "Show weekends" : "Näytä viikonloput",
+    "Show week numbers" : "Näytä viikkonumerot",
+    "Time increments" : "Aikavälit",
+    "Copy primary CalDAV address" : "Kopioi ensisijainen CalDAV-osoite",
+    "Copy iOS/macOS CalDAV address" : "Kopioi iOS:in/macOS:n CalDAV-osoite",
+    "Personal availability settings" : "Henkilökohtaiset saatavuusasetukset",
+    "Show keyboard shortcuts" : "Näytä pikanäppäimet",
+    "Create a new public conversation" : "Luo uusi julkinen keskustelu",
+    "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} kutsuttu, {confirmedCount} vahvistettu",
+    "Successfully appended link to talk room to description." : "Linkki Talk-huoneeseen lisättiin onnistuneesti kuvaukseen.",
+    "Error creating Talk room" : "Virhe luotaessa Talk-huonetta",
+    "Event title" : "Tapahtuman otsikko",
+    "_time_::_times_" : ["kerran","kertaa"],
+    "Select to end repeat" : "Valitse lopettaaksesi toiston",
+    "from {formattedDate}" : "alkaen {formattedDate}",
+    "to {formattedDate}" : "päättyen {formattedDate}",
+    "on {formattedDate}" : "päivänä {formattedDate}",
+    "from {formattedDate} at {formattedTime}" : "alkaen {formattedDate} klo {formattedTime}",
+    "to {formattedDate} at {formattedTime}" : "päättyen {formattedDate} klo {formattedTime}",
+    "on {formattedDate} at {formattedTime}" : "päivänä {formattedDate} klo {formattedTime}",
+    "{formattedDate} at {formattedTime}" : "{formattedDate} klo {formattedTime}",
+    "Please enter a valid date" : "Kirjoita kelvollinen päivä",
+    "Please enter a valid date and time" : "Kirjoita kelvollinen päivä ja aika",
+    "Select a time zone" : "Valitse aikavyöhyke",
+    "Please select a time zone:" : "Valitse aikavyöhyke:",
+    "Pick a time" : "Valitse aika",
+    "Pick a date" : "Valitse päivä",
+    "The visibility of this event in shared calendars." : "Tämän tapahtuman näkyvyys jaetuissa kalentereissa.",
+    "Calendar name …" : "Kalenterin nimi …",
+    "15 min" : "15 min",
+    "30 min" : "30 min",
+    "60 min" : "60 min",
+    "90 min" : "90 min"
 },
 "nplurals=2; plural=(n != 1);");
