@@ -39,6 +39,7 @@ OC.L10N.register(
     "Comment:" : "Comentariu:",
     "You have a new appointment booking \"%s\" from %s" : "Aveți o nouă rezervare \"%s\" de la %s",
     "Dear %s, %s (%s) booked an appointment with you." : "Dragă %s, %s (%s) a rezervat o întâlnire cu tine.",
+    "Location:" : "Locaţie:",
     "A Calendar app for Nextcloud" : "O aplicație de tip calendar pentru Nextcloud",
     "Previous day" : "Ziua anterioară",
     "Previous week" : "Săptămâna anterioară",
@@ -60,6 +61,7 @@ OC.L10N.register(
     "Appointment link could not be copied to clipboard" : "Linkul programării nu a putut fi copiat în clipboard",
     "Preview" : "Previzualizare",
     "Copy link" : "Copiază link",
+    "Duplicate" : "Duplicat",
     "Edit" : "Editează",
     "Delete" : "Șterge",
     "Create new" : "Crează nou",
@@ -68,8 +70,11 @@ OC.L10N.register(
     "Enable calendar \"{calendar}\"" : "Activează calendarul \"{calendar}\"",
     "Enable untitled calendar" : "Activează calendarul fără nume",
     "An error occurred, unable to change visibility of the calendar." : "A apărut o eroare, nu se poate schimba vizibilitatea calendarului.",
+    "Calendar link copied to clipboard." : "Linkul către calendar a fost copiat în clipboard.",
+    "Calendar link could not be copied to clipboard." : "Linkul către calendar nu a putut fi copiat în clipboard.",
     "Untitled calendar" : "Calendar nedenumit",
     "Shared with you by" : "Partajat cu tine de",
+    "Copy public link" : "Copiză link-ul public",
     "Edit and share calendar" : "Editează și partajează calendarul",
     "Edit calendar" : "Editare calendar",
     "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Oprirea partajării calendarului in {countdown} secundă","Oprirea partajării calendarului în {countdown} secunde","Oprirea partajării calendarului în {countdown} de secunde"],
@@ -85,8 +90,6 @@ OC.L10N.register(
     "New subscription from link (read-only)" : "Abonament nou folosind un link (doar citirea calendarului)",
     "Creating subscription …" : "Se creează abonamentul ...",
     "Add public holiday calendar" : "Adaugă calendar de sărbători",
-    "Calendar link copied to clipboard." : "Linkul către calendar a fost copiat în clipboard.",
-    "Calendar link could not be copied to clipboard." : "Linkul către calendar nu a putut fi copiat în clipboard.",
     "Copy subscription link" : "Copiază linkul abonamentului",
     "Copying link …" : "Copiază link ...",
     "Copied link" : "Link copiat",
@@ -107,7 +110,6 @@ OC.L10N.register(
     "Delete permanently" : "Șterge permanent",
     "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Coșul de gunoi este golit în {numDays} zi","Coșul de gunoi este golit în {numDays} zile","Coșul de gunoi este golit în {numDays} zile"],
     "Could not update calendar order." : "Nu s-a putut actualiza ordinea calendarului.",
-    "Hidden" : "Ascuns",
     "Internal link" : "Link intern",
     "A private link that can be used with external clients" : "Link privat ce poate fi folosit cu clienți externi",
     "Copy internal link" : "Copiază linkul intern",
@@ -117,7 +119,6 @@ OC.L10N.register(
     "Embed code could not be copied to clipboard." : "Codul nu a putut fi copiat in clipboard.",
     "Unpublishing calendar failed" : "Retragerea calendarului a eşuat",
     "Share link" : "Partajază legătură",
-    "Copy public link" : "Copiză link-ul public",
     "Send link to calendar via email" : "Trimite link-ul către calendar folosind email",
     "Enter one address" : "Introdu o adresă",
     "Sending email …" : "Email-ul se trimite ...",
@@ -129,15 +130,14 @@ OC.L10N.register(
     "Deleting share link …" : "Se şterge linkul de partajare ...",
     "An error occurred while unsharing the calendar." : "Eroare la eliminarea partajării calendarului.",
     "An error occurred, unable to change the permission of the share." : "A apărut o eroare, nu se poate schimba permisiunile fişierelor partajate.",
-    "can edit" : "poate edita",
     "Unshare with {displayName}" : "Retrage cu {displayName}",
     "Share with users or groups" : "Partajează cu utilizatori sau grupuri",
     "No users or groups" : "Nu sunt utilizatori sau grupuri",
     "Failed to save calendar name and color" : "Eroare la salvarea numelui calendarului și a culorii",
-    "Calendar name …" : "Numele calendarului ...",
     "Share calendar" : "Partajează calendarul",
     "Unshare from me" : "Anulare partajarea cu mine",
     "Save" : "Salvează",
+    "View" : "Vizualizare",
     "Import calendars" : "Importă calendare",
     "Please select a calendar to import into …" : "Vă rugăm să selectaţi un calendar în care să importaţi ...",
     "Filename" : "Nume fișier",
@@ -148,13 +148,13 @@ OC.L10N.register(
     "Invalid location selected" : "Locație invalidă",
     "Attachments folder successfully saved." : "Folderul de atașamente a fost salvat.",
     "Error on saving attachments folder." : "Eroare la salvarea folderului de atașamente.",
-    "Default attachments location" : "Locația implicită a atașamentelor",
+    "Attachments folder" : "Dosarul pentru atașamente",
     "{filename} could not be parsed" : "{filename} nu a putut fi analizat",
     "No valid files found, aborting import" : "Nu au fost găsite fişiere valide, importarea se opreşte",
     "_Successfully imported %n event_::_Successfully imported %n events_" : ["A fost importat %n eveniment","Au fost importate %n evenimente","Au fost importate %n evenimente"],
     "Import partially failed. Imported {accepted} out of {total}." : "Importarea a eşuat parţial. S-au importat  {accepted} din {total}.",
     "Automatic" : "Automat",
-    "Automatic ({detected})" : "Automat ({detectat})",
+    "Automatic ({timezone})" : "Automat ({detectat})",
     "New setting was not saved successfully." : "Noile setări nu au fost salvate cu succes.",
     "Navigation" : "Navigare",
     "Previous period" : "Perioada anterioară",
@@ -172,24 +172,13 @@ OC.L10N.register(
     "Save edited event" : "Salvează evenimentul editat",
     "Delete edited event" : "Șterge evenimentul editat",
     "Duplicate event" : "Duplicare eveniment",
-    "Shortcut overview" : "Prezentare generală a comenzilor rapide",
     "or" : "sau",
     "Calendar settings" : "Setări calendar",
     "No reminder" : "Fără mementouri",
-    "CalDAV link copied to clipboard." : "Link-ul CAlDAV a fost copiat în clipboard.",
-    "CalDAV link could not be copied to clipboard." : "Linkul CalDAV nu a putut fi copiat în clipboard.",
-    "Enable birthday calendar" : "Activează calendarul cu zile de naştere",
-    "Show tasks in calendar" : "Arată sarcinile în calendar",
-    "Enable simplified editor" : "Activează editorul simplificat",
-    "Limit the number of events displayed in the monthly view" : "Limitează numărul evenimentelor în vizualizare lunară",
-    "Show weekends" : "Arată weekend-uri",
-    "Show week numbers" : "Afișați numerele săptămânilor",
-    "Time increments" : "Incremente de timp",
+    "General" : "General",
+    "Appearance" : "Aspect",
+    "Editing" : "Se modifică",
     "Default reminder" : "Memento implicit",
-    "Copy primary CalDAV address" : "Copiază adresa primară CalDAV",
-    "Copy iOS/macOS CalDAV address" : "Copiază adresa iOS/OS X CalDAV",
-    "Personal availability settings" : "Setări de disponibilitate",
-    "Show keyboard shortcuts" : "Arată scurtături",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minut","{duration} minute","{duration} de minute"],
     "0 minutes" : "0 minute",
     "_{duration} hour_::_{duration} hours_" : ["{duration} oră","{duration} ore","{duration} de ore"],
@@ -291,10 +280,8 @@ OC.L10N.register(
     "Accept" : "Accept",
     "Decline" : "Refuză",
     "Tentative" : "Tentativă",
+    "Copied to clipboard" : "Copiat în clipboard",
     "No attendees yet" : "Nu exista participați încă",
-    "Successfully appended link to talk room to location." : "S-a adăugat cu succes locației linkul la camera Talk.",
-    "Successfully appended link to talk room to description." : "S-a adăugat cu succes descrierii linkul la camera Talk.",
-    "Error creating Talk room" : "Camera Talk nu a putut fi creată",
     "Attendees" : "Participanți",
     "Remove group" : "Înlătură grupul",
     "Remove attendee" : "Elimină participant",
@@ -306,17 +293,15 @@ OC.L10N.register(
     "(organizer)" : "(organizator)",
     "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Pentru a trimite invitații și răspunsuri, [linkopen]adăugați adresa de mail în setările personale[linkclose].",
     "Remove color" : "Șterge culoarea",
-    "Event title" : "Titlul evenimentului",
+    "Title" : "Titlu",
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Nu se pot modifica setările zilnice pentru evenimentele care fac parte dintr-un set recurent.",
     "From" : "De la",
     "To" : "Către",
     "Repeat" : "Repetă",
-    "_time_::_times_" : ["dată","ori","ori"],
     "never" : "niciodată",
     "on date" : "la data ",
     "after" : "după",
     "End repeat" : "Încheie seria",
-    "Select to end repeat" : "Selectează pentru a încheia seria",
     "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Acest eveniment este excepția de recurență a unui set recurent. Nu i se poate adăuga o regulă de recurență.",
     "first" : "primul",
     "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Modificările regulii de recurență se vor aplica  doar de acum încolo.",
@@ -351,18 +336,11 @@ OC.L10N.register(
     "Update this occurrence" : "Actualizați această ședință",
     "Public calendar does not exist" : "Calendarul public nu există",
     "Maybe the share was deleted or has expired?" : "Poate că partajarea a fost ștearsă sau a expirat?",
-    "from {formattedDate}" : "începând cu {formattedDate}",
-    "to {formattedDate}" : "până la {formattedDate}",
-    "on {formattedDate}" : "pe {formattedDate}",
-    "from {formattedDate} at {formattedTime}" : "începând cu {formattedDate} la {formattedTime}",
-    "to {formattedDate} at {formattedTime}" : "până la data {formattedDate} la {formattedTime}",
-    "on {formattedDate} at {formattedTime}" : "pe {formattedDate} la {formattedTime}",
-    "{formattedDate} at {formattedTime}" : "{formattedDate} la {formattedTime}",
-    "Please enter a valid date" : "Adăugați o dată validă",
-    "Please enter a valid date and time" : "Adăugați o dată validă și o oră",
-    "Please select a time zone:" : "Te rugăm să alegeți un fus orar:",
-    "Pick a time" : "Alege un interval orar",
-    "Pick a date" : "Alege o dată",
+    "Remove participant" : "Elimină participant",
+    "Yes" : "Da",
+    "No" : "Nu",
+    "None" : "Niciuna",
+    "Create" : "Crează",
     "Type to search time zone" : "Tastați pentru căutare zonă de timp",
     "Global" : "Global",
     "Holidays in {region}" : "Sărbători în {region}",
@@ -388,9 +366,9 @@ OC.L10N.register(
     "Personal" : "Personal",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "A fost detectată automat zona de timp ca fiind UTC.\nProbabil ca măsura de securitate în cadrul browserului.\nSetați zona de timp manual în setările Calendar.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Zona de timp ({timezoneId}) nu există. Se revenire la UTC.\nModificați zona de timp în setări și raportați această problemă.",
+    "Discard changes" : "Anulează modificările",
     "Edit event" : "Modifică eveniment",
     "Event does not exist" : "Evenimentul nu există",
-    "Duplicate" : "Duplicat",
     "Delete this occurrence" : "Șterge această poziție",
     "Delete this and all future" : "Șterge aceasta și toate viitoare",
     "All day" : "Toată ziua",
@@ -401,6 +379,9 @@ OC.L10N.register(
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Atașament care necesită acces partajat","Atașamente care necesită acces partajat","Atașamente care necesită acces partajat"],
     "Untitled event" : "Eveniment fără titlu",
     "Close" : "Închide",
+    "This event was cancelled" : "Acest eveniment a fost anulat",
+    "Participants" : "Participanți",
+    "Submit" : "Trimite",
     "Subscribe to {name}" : "Abonare la {name}",
     "Export {name}" : "Exportă {name}",
     "Anniversary" : "Aniversare",
@@ -468,7 +449,6 @@ OC.L10N.register(
     "When shared show full event" : "Arată tot evenimentul la partajare",
     "When shared show only busy" : "Arată doar ocupat la partajare",
     "When shared hide this event" : "Ascunde evenimentul la partajare",
-    "The visibility of this event in shared calendars." : "Vizibilitatea acestui eveniment în calendarele partajate.",
     "Add a location" : "Adaugă o locație",
     "Status" : "Stare",
     "Confirmed" : "Confirmat",
@@ -491,10 +471,43 @@ OC.L10N.register(
     "This is an event reminder." : "Acesta este un memento pentru eveniment.",
     "Appointment not found" : "Programarea nu a fost găsită",
     "User not found" : "Utilizatorul nu a fost găsit",
-    "Create a new conversation" : "Creează o nouă conversație",
-    "Reminder" : "Memento",
-    "+ Add reminder" : "+ Adaugă memento",
-    "Suggestions" : "Sugestii",
-    "Details" : "Detalii"
+    "Hidden" : "Ascuns",
+    "can edit" : "poate edita",
+    "Calendar name …" : "Numele calendarului ...",
+    "Default attachments location" : "Locația implicită a atașamentelor",
+    "Automatic ({detected})" : "Automat ({detectat})",
+    "Shortcut overview" : "Prezentare generală a comenzilor rapide",
+    "CalDAV link copied to clipboard." : "Link-ul CAlDAV a fost copiat în clipboard.",
+    "CalDAV link could not be copied to clipboard." : "Linkul CalDAV nu a putut fi copiat în clipboard.",
+    "Enable birthday calendar" : "Activează calendarul cu zile de naştere",
+    "Show tasks in calendar" : "Arată sarcinile în calendar",
+    "Enable simplified editor" : "Activează editorul simplificat",
+    "Limit the number of events displayed in the monthly view" : "Limitează numărul evenimentelor în vizualizare lunară",
+    "Show weekends" : "Arată weekend-uri",
+    "Show week numbers" : "Afișați numerele săptămânilor",
+    "Time increments" : "Incremente de timp",
+    "Copy primary CalDAV address" : "Copiază adresa primară CalDAV",
+    "Copy iOS/macOS CalDAV address" : "Copiază adresa iOS/OS X CalDAV",
+    "Personal availability settings" : "Setări de disponibilitate",
+    "Show keyboard shortcuts" : "Arată scurtături",
+    "Successfully appended link to talk room to location." : "S-a adăugat cu succes locației linkul la camera Talk.",
+    "Successfully appended link to talk room to description." : "S-a adăugat cu succes descrierii linkul la camera Talk.",
+    "Error creating Talk room" : "Camera Talk nu a putut fi creată",
+    "Event title" : "Titlul evenimentului",
+    "_time_::_times_" : ["dată","ori","ori"],
+    "Select to end repeat" : "Selectează pentru a încheia seria",
+    "from {formattedDate}" : "începând cu {formattedDate}",
+    "to {formattedDate}" : "până la {formattedDate}",
+    "on {formattedDate}" : "pe {formattedDate}",
+    "from {formattedDate} at {formattedTime}" : "începând cu {formattedDate} la {formattedTime}",
+    "to {formattedDate} at {formattedTime}" : "până la data {formattedDate} la {formattedTime}",
+    "on {formattedDate} at {formattedTime}" : "pe {formattedDate} la {formattedTime}",
+    "{formattedDate} at {formattedTime}" : "{formattedDate} la {formattedTime}",
+    "Please enter a valid date" : "Adăugați o dată validă",
+    "Please enter a valid date and time" : "Adăugați o dată validă și o oră",
+    "Please select a time zone:" : "Te rugăm să alegeți un fus orar:",
+    "Pick a time" : "Alege un interval orar",
+    "Pick a date" : "Alege o dată",
+    "The visibility of this event in shared calendars." : "Vizibilitatea acestui eveniment în calendarele partajate."
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
